@@ -16,7 +16,7 @@ class FilterHtml : public FilterX
 public:
   FilterHtml (FILE* filein, FILE* fileout, bool isUniIn, bool isUniOut);
 
-  bool GetNextToken (wchar_t* token, bool* thaiFlag);
+  bool GetNextToken (wchar_t* token, int tokenSz, bool* thaiFlag);
   void Print (const wchar_t* token, bool thaiFlag);
 
 private:
