@@ -43,10 +43,12 @@ FilterLatex::GetNextToken (wchar_t* token, int tokenSz, bool* thaiFlag)
   if (verbatim)
     {
       *thaiFlag = false;
+      wchar_t* curPtr = buffer;
       wchar_t* stVer = wcsstr (buffer, L"\\end{verbatim}");
       if (!stVer)
         {
-          consumeToken (token, tokenSz, buffer, wcslen (buffer));
+          curPtr += consumeToken (token, tokenSz, buffer, wcslen (buffer));
+          wmemmove (buffer, curPtr, wcslen (curPtr) + 1);
         }
       else
         {
@@ -55,7 +57,8 @@ FilterLatex::GetNextToken (wchar_t* token, int tokenSz, bool* thaiFlag)
             {
               stVer += verbLen;
             }
-          consumeToken (token, tokenSz, buffer, stVer - buffer);
+          curPtr += consumeToken (token, tokenSz, buffer, stVer - buffer);
+          wmemmove (buffer, curPtr, wcslen (curPtr) + 1);
           verbatim = false;
         }
       return true;
@@ -94,38 +97,37 @@ FilterLatex::GetNextToken (wchar_t* token, int tokenSz, bool* thaiFlag)
               wmemmove (buffer, beginPtr, wcslen (beginPtr) + 1);
               return true;
             }
-          else
+
+          // EOL is found
+          if (*curPtr == L'\n')
             {
-              if (*curPtr == L'\n')
+              *curPtr = 0;
+            }
+          int tkLen = consumeToken (pToken, tokenSz,
+                                    beginPtr, curPtr - beginPtr);
+          pToken += tkLen;
+          tokenSz -= tkLen;
+          lastAllowed -= tkLen;
+          //if next a line is thai string, concat next line
+          // to current line
+          if (!ConvGetS (buffer, N_ELM (buffer), fpin, isUniIn))
+            {
+              if (tokenSz > 1)
                 {
-                  *curPtr = 0;
+                  wcscpy (pToken, L"\n");
                 }
-              int tkLen = consumeToken (pToken, tokenSz,
-                                        beginPtr, curPtr - beginPtr);
-              pToken += tkLen;
-              tokenSz -= tkLen;
-              lastAllowed -= tkLen;
-              //if next a line is thai string, concat next line
-              // to current line
-              if (!ConvGetS (buffer, N_ELM (buffer), fpin, isUniIn))
-                {
-                  if (tokenSz > 1)
-                    {
-                      wcscpy (pToken, L"\n");
-                    }
-                  return true;  //next GetToken() must return false
-                }
-              beginPtr = curPtr = buffer;
+              return true;  //next GetToken() must return false
+            }
+          beginPtr = curPtr = buffer;
 #ifdef CAT_THAI_LINES
-              if (!isThaiUni (*curPtr))    //not thai character
+          if (!isThaiUni (*curPtr))    //not thai character
 #endif
+            {
+              if (tokenSz > 1)
                 {
-                  if (tokenSz > 1)
-                    {
-                      wcscpy (pToken, L"\n");
-                    }
-                  return true;
+                  wcscpy (pToken, L"\n");
                 }
+              return true;
             }
         }
     }
@@ -148,7 +150,8 @@ FilterLatex::GetNextToken (wchar_t* token, int tokenSz, bool* thaiFlag)
   return true;
 
 get_cur_token_return:
-  consumeToken (pToken, tokenSz, beginPtr, curPtr - beginPtr);
+  beginPtr += consumeToken (pToken, tokenSz, beginPtr, curPtr - beginPtr);
+  wmemmove (buffer, beginPtr, wcslen (beginPtr) + 1);
   return true;
 }
 
